@@ -14,6 +14,9 @@ pub fn add_cli_context(mut engine_state: EngineState) -> EngineState {
 
         bind_command! {
             Commandline,
+            CommandlineEdit,
+            CommandlineGetCursor,
+            CommandlineSetCursor,
             History,
             HistorySession,
             Keybindings,
