@@ -57,7 +57,7 @@ impl NuHelpCompleter {
 
                 if !sig.named.is_empty() {
                     long_desc.push_str(&get_flags_section(Some(&*self.0.clone()), sig, |v| {
-                        v.into_string_parsable(", ", &self.0.config)
+                        v.to_parsable_string(", ", &self.0.config)
                     }))
                 }
 
@@ -73,7 +73,7 @@ impl NuHelpCompleter {
                         let opt_suffix = if let Some(value) = &positional.default_value {
                             format!(
                                 " (optional, default: {})",
-                                &value.into_string_parsable(", ", &self.0.config),
+                                &value.to_parsable_string(", ", &self.0.config),
                             )
                         } else {
                             (" (optional)").to_string()
