@@ -84,7 +84,7 @@ pub(crate) fn add_menus(
     }
 
     // Checking if the default menus have been added from the config file
-    let default_menus = vec![
+    let default_menus = [
         ("completion_menu", DEFAULT_COMPLETION_MENU),
         ("history_menu", DEFAULT_HISTORY_MENU),
         ("help_menu", DEFAULT_HELP_MENU),
@@ -94,7 +94,7 @@ pub(crate) fn add_menus(
         if !config
             .menus
             .iter()
-            .any(|menu| menu.name.into_string("", config) == name)
+            .any(|menu| menu.name.to_expanded_string("", config) == name)
         {
             let (block, _) = {
                 let mut working_set = StateWorkingSet::new(&engine_state);
@@ -133,7 +133,7 @@ fn add_menu(
 ) -> Result<Reedline, ShellError> {
     let span = menu.menu_type.span();
     if let Value::Record { val, .. } = &menu.menu_type {
-        let layout = extract_value("layout", val, span)?.into_string("", config);
+        let layout = extract_value("layout", val, span)?.to_expanded_string("", config);
 
         match layout.as_str() {
             "columnar" => add_columnar_menu(line_editor, menu, engine_state, stack, config),
@@ -142,14 +142,14 @@ fn add_menu(
             "description" => add_description_menu(line_editor, menu, engine_state, stack, config),
             _ => Err(ShellError::UnsupportedConfigValue {
                 expected: "columnar, list, ide or description".to_string(),
-                value: menu.menu_type.into_abbreviated_string(config),
+                value: menu.menu_type.to_abbreviated_string(config),
                 span: menu.menu_type.span(),
             }),
         }
     } else {
         Err(ShellError::UnsupportedConfigValue {
             expected: "only record type".to_string(),
-            value: menu.menu_type.into_abbreviated_string(config),
+            value: menu.menu_type.to_abbreviated_string(config),
             span: menu.menu_type.span(),
         })
     }
@@ -181,7 +181,7 @@ pub(crate) fn add_columnar_menu(
     config: &Config,
 ) -> Result<Reedline, ShellError> {
     let span = menu.menu_type.span();
-    let name = menu.name.into_string("", config);
+    let name = menu.name.to_expanded_string("", config);
     let mut columnar_menu = ColumnarMenu::default().with_name(&name);
 
     if let Value::Record { val, .. } = &menu.menu_type {
@@ -254,7 +254,7 @@ pub(crate) fn add_columnar_menu(
         );
     }
 
-    let marker = menu.marker.into_string("", config);
+    let marker = menu.marker.to_expanded_string("", config);
     columnar_menu = columnar_menu.with_marker(&marker);
 
     let only_buffer_difference = menu.only_buffer_difference.as_bool()?;
@@ -280,7 +280,7 @@ pub(crate) fn add_columnar_menu(
         }
         _ => Err(ShellError::UnsupportedConfigValue {
             expected: "block or omitted value".to_string(),
-            value: menu.source.into_abbreviated_string(config),
+            value: menu.source.to_abbreviated_string(config),
             span,
         }),
     }
@@ -294,7 +294,7 @@ pub(crate) fn add_list_menu(
     stack: &Stack,
     config: &Config,
 ) -> Result<Reedline, ShellError> {
-    let name = menu.name.into_string("", config);
+    let name = menu.name.to_expanded_string("", config);
     let mut list_menu = ListMenu::default().with_name(&name);
 
     let span = menu.menu_type.span();
@@ -336,7 +336,7 @@ pub(crate) fn add_list_menu(
         );
     }
 
-    let marker = menu.marker.into_string("", config);
+    let marker = menu.marker.to_expanded_string("", config);
     list_menu = list_menu.with_marker(&marker);
 
     let only_buffer_difference = menu.only_buffer_difference.as_bool()?;
@@ -362,7 +362,7 @@ pub(crate) fn add_list_menu(
         }
         _ => Err(ShellError::UnsupportedConfigValue {
             expected: "block or omitted value".to_string(),
-            value: menu.source.into_abbreviated_string(config),
+            value: menu.source.to_abbreviated_string(config),
             span: menu.source.span(),
         }),
     }
@@ -377,7 +377,7 @@ pub(crate) fn add_ide_menu(
     config: &Config,
 ) -> Result<Reedline, ShellError> {
     let span = menu.menu_type.span();
-    let name = menu.name.into_string("", config);
+    let name = menu.name.to_expanded_string("", config);
     let mut ide_menu = IdeMenu::default().with_name(&name);
 
     if let Value::Record { val, .. } = &menu.menu_type {
@@ -402,7 +402,7 @@ pub(crate) fn add_ide_menu(
                 let max_completion_height = max_completion_height.as_int()?;
                 ide_menu.with_max_completion_height(max_completion_height as u16)
             }
-            Err(_) => ide_menu,
+            Err(_) => ide_menu.with_max_completion_height(10u16),
         };
 
         ide_menu = match extract_value("padding", val, span) {
@@ -442,12 +442,12 @@ pub(crate) fn add_ide_menu(
                 } else {
                     return Err(ShellError::UnsupportedConfigValue {
                         expected: "bool or record".to_string(),
-                        value: border.into_abbreviated_string(config),
+                        value: border.to_abbreviated_string(config),
                         span: border.span(),
                     });
                 }
             }
-            Err(_) => ide_menu,
+            Err(_) => ide_menu.with_default_border(),
         };
 
         ide_menu = match extract_value("cursor_offset", val, span) {
@@ -459,21 +459,18 @@ pub(crate) fn add_ide_menu(
         };
 
         ide_menu = match extract_value("description_mode", val, span) {
-            Ok(description_mode) => {
-                let description_mode_str = description_mode.as_string()?;
-                match description_mode_str.as_str() {
-                    "left" => ide_menu.with_description_mode(DescriptionMode::Left),
-                    "right" => ide_menu.with_description_mode(DescriptionMode::Right),
-                    "prefer_right" => ide_menu.with_description_mode(DescriptionMode::PreferRight),
-                    _ => {
-                        return Err(ShellError::UnsupportedConfigValue {
-                            expected: "\"left\", \"right\" or \"prefer_right\"".to_string(),
-                            value: description_mode.into_abbreviated_string(config),
-                            span: description_mode.span(),
-                        });
-                    }
+            Ok(description_mode) => match description_mode.coerce_str()?.as_ref() {
+                "left" => ide_menu.with_description_mode(DescriptionMode::Left),
+                "right" => ide_menu.with_description_mode(DescriptionMode::Right),
+                "prefer_right" => ide_menu.with_description_mode(DescriptionMode::PreferRight),
+                _ => {
+                    return Err(ShellError::UnsupportedConfigValue {
+                        expected: "\"left\", \"right\" or \"prefer_right\"".to_string(),
+                        value: description_mode.to_abbreviated_string(config),
+                        span: description_mode.span(),
+                    });
                 }
-            }
+            },
             Err(_) => ide_menu,
         };
 
@@ -562,7 +559,7 @@ pub(crate) fn add_ide_menu(
         );
     }
 
-    let marker = menu.marker.into_string("", config);
+    let marker = menu.marker.to_expanded_string("", config);
     ide_menu = ide_menu.with_marker(&marker);
 
     let only_buffer_difference = menu.only_buffer_difference.as_bool()?;
@@ -588,7 +585,7 @@ pub(crate) fn add_ide_menu(
         }
         _ => Err(ShellError::UnsupportedConfigValue {
             expected: "block or omitted value".to_string(),
-            value: menu.source.into_abbreviated_string(config),
+            value: menu.source.to_abbreviated_string(config),
             span,
         }),
     }
@@ -602,7 +599,7 @@ pub(crate) fn add_description_menu(
     stack: &Stack,
     config: &Config,
 ) -> Result<Reedline, ShellError> {
-    let name = menu.name.into_string("", config);
+    let name = menu.name.to_expanded_string("", config);
     let mut description_menu = DescriptionMenu::default().with_name(&name);
 
     let span = menu.menu_type.span();
@@ -676,7 +673,7 @@ pub(crate) fn add_description_menu(
         );
     }
 
-    let marker = menu.marker.into_string("", config);
+    let marker = menu.marker.to_expanded_string("", config);
     description_menu = description_menu.with_marker(&marker);
 
     let only_buffer_difference = menu.only_buffer_difference.as_bool()?;
@@ -706,7 +703,7 @@ pub(crate) fn add_description_menu(
         }
         _ => Err(ShellError::UnsupportedConfigValue {
             expected: "closure or omitted value".to_string(),
-            value: menu.source.into_abbreviated_string(config),
+            value: menu.source.to_abbreviated_string(config),
             span: menu.source.span(),
         }),
     }
@@ -845,7 +842,7 @@ fn add_keybinding(
         }
         v => Err(ShellError::UnsupportedConfigValue {
             expected: "string or list of strings".to_string(),
-            value: v.into_abbreviated_string(config),
+            value: v.to_abbreviated_string(config),
             span: v.span(),
         }),
     }
@@ -858,7 +855,7 @@ fn add_parsed_keybinding(
 ) -> Result<(), ShellError> {
     let modifier = match keybinding
         .modifier
-        .into_string("", config)
+        .to_expanded_string("", config)
         .to_ascii_lowercase()
         .as_str()
     {
@@ -875,7 +872,7 @@ fn add_parsed_keybinding(
         _ => {
             return Err(ShellError::UnsupportedConfigValue {
                 expected: "CONTROL, SHIFT, ALT or NONE".to_string(),
-                value: keybinding.modifier.into_abbreviated_string(config),
+                value: keybinding.modifier.to_abbreviated_string(config),
                 span: keybinding.modifier.span(),
             })
         }
@@ -883,7 +880,7 @@ fn add_parsed_keybinding(
 
     let keycode = match keybinding
         .keycode
-        .into_string("", config)
+        .to_expanded_string("", config)
         .to_ascii_lowercase()
         .as_str()
     {
@@ -936,7 +933,7 @@ fn add_parsed_keybinding(
         _ => {
             return Err(ShellError::UnsupportedConfigValue {
                 expected: "crossterm KeyCode".to_string(),
-                value: keybinding.keycode.into_abbreviated_string(config),
+                value: keybinding.keycode.to_abbreviated_string(config),
                 span: keybinding.keycode.span(),
             })
         }
@@ -974,7 +971,10 @@ fn parse_event(value: &Value, config: &Config) -> Result<Option<ReedlineEvent>,
     match value {
         Value::Record { val: record, .. } => match EventType::try_from_record(record, span)? {
             EventType::Send(value) => event_from_record(
-                value.into_string("", config).to_ascii_lowercase().as_str(),
+                value
+                    .to_expanded_string("", config)
+                    .to_ascii_lowercase()
+                    .as_str(),
                 record,
                 config,
                 span,
@@ -982,7 +982,10 @@ fn parse_event(value: &Value, config: &Config) -> Result<Option<ReedlineEvent>,
             .map(Some),
             EventType::Edit(value) => {
                 let edit = edit_from_record(
-                    value.into_string("", config).to_ascii_lowercase().as_str(),
+                    value
+                        .to_expanded_string("", config)
+                        .to_ascii_lowercase()
+                        .as_str(),
                     record,
                     config,
                     span,
@@ -1010,7 +1013,7 @@ fn parse_event(value: &Value, config: &Config) -> Result<Option<ReedlineEvent>,
                 }
                 v => Err(ShellError::UnsupportedConfigValue {
                     expected: "list of events".to_string(),
-                    value: v.into_abbreviated_string(config),
+                    value: v.to_abbreviated_string(config),
                     span: v.span(),
                 }),
             },
@@ -1036,7 +1039,7 @@ fn parse_event(value: &Value, config: &Config) -> Result<Option<ReedlineEvent>,
         Value::Nothing { .. } => Ok(None),
         v => Err(ShellError::UnsupportedConfigValue {
             expected: "record or list of records, null to unbind key".to_string(),
-            value: v.into_abbreviated_string(config),
+            value: v.to_abbreviated_string(config),
             span: v.span(),
         }),
     }
@@ -1079,11 +1082,11 @@ fn event_from_record(
         "openeditor" => ReedlineEvent::OpenEditor,
         "menu" => {
             let menu = extract_value("name", record, span)?;
-            ReedlineEvent::Menu(menu.into_string("", config))
+            ReedlineEvent::Menu(menu.to_expanded_string("", config))
         }
         "executehostcommand" => {
             let cmd = extract_value("cmd", record, span)?;
-            ReedlineEvent::ExecuteHostCommand(cmd.into_string("", config))
+            ReedlineEvent::ExecuteHostCommand(cmd.to_expanded_string("", config))
         }
         v => {
             return Err(ShellError::UnsupportedConfigValue {
@@ -1188,7 +1191,7 @@ fn edit_from_record(
         }
         "insertstring" => {
             let value = extract_value("value", record, span)?;
-            EditCommand::InsertString(value.into_string("", config))
+            EditCommand::InsertString(value.to_expanded_string("", config))
         }
         "insertnewline" => EditCommand::InsertNewline,
         "backspace" => EditCommand::Backspace,
@@ -1289,7 +1292,7 @@ fn edit_from_record(
 fn extract_char(value: &Value, config: &Config) -> Result<char, ShellError> {
     let span = value.span();
     value
-        .into_string("", config)
+        .to_expanded_string("", config)
         .chars()
         .next()
         .ok_or_else(|| ShellError::MissingConfigValue {
