@@ -106,7 +106,7 @@ impl Command for MeltDF {
                             Value::test_string("c"),
                         ],
                     ),
-                ])
+                ], None)
                 .expect("simple df for test should not fail")
                 .into_value(Span::test_data()),
             ),
