@@ -1,9 +1,12 @@
+use crate::dataframe::values::NuSchema;
+
 use super::super::values::{NuDataFrame, NuLazyFrame};
 
+use nu_engine::CallExt;
 use nu_protocol::{
     ast::Call,
     engine::{Command, EngineState, Stack},
-    Category, Example, PipelineData, ShellError, Signature, Type, Value,
+    Category, Example, PipelineData, ShellError, Signature, SyntaxShape, Type, Value,
 };
 
 #[derive(Clone)]
@@ -20,6 +23,12 @@ impl Command for ToLazyFrame {
 
     fn signature(&self) -> Signature {
         Signature::build(self.name())
+            .named(
+                "schema",
+                SyntaxShape::Record(vec![]),
+                r#"Polars Schema in format [{name: str}]. CSV, JSON, and JSONL files"#,
+                Some('s'),
+            )
             .input_output_type(Type::Any, Type::Custom("dataframe".into()))
             .category(Category::Custom("lazyframe".into()))
     }
@@ -34,12 +43,17 @@ impl Command for ToLazyFrame {
 
     fn run(
         &self,
-        _engine_state: &EngineState,
-        _stack: &mut Stack,
+        engine_state: &EngineState,
+        stack: &mut Stack,
         call: &Call,
         input: PipelineData,
     ) -> Result<PipelineData, ShellError> {
-        let df = NuDataFrame::try_from_iter(input.into_iter())?;
+        let maybe_schema = call
+            .get_flag(engine_state, stack, "schema")?
+            .map(|schema| NuSchema::try_from(&schema))
+            .transpose()?;
+
+        let df = NuDataFrame::try_from_iter(input.into_iter(), maybe_schema)?;
         let lazy = NuLazyFrame::from_dataframe(df);
         let value = Value::custom_value(Box::new(lazy), call.head);
 
