@@ -6,7 +6,10 @@ use nu_protocol::{
     engine::{Command, EngineState, Stack},
     Category, Example, PipelineData, ShellError, Signature, Span, SyntaxShape, Type, Value,
 };
-use polars::prelude::{IntoSeries, StringNameSpaceImpl};
+use polars::{
+    prelude::{IntoSeries, NamedFrom, StringNameSpaceImpl},
+    series::Series,
+};
 
 #[derive(Clone)]
 pub struct StrSlice;
@@ -32,25 +35,46 @@ impl Command for StrSlice {
     }
 
     fn examples(&self) -> Vec<Example> {
-        vec![Example {
-            description: "Creates slices from the strings",
-            example: "[abcded abc321 abc123] | dfr into-df | dfr str-slice 1 --length 2",
-            result: Some(
-                NuDataFrame::try_from_columns(
-                    vec![Column::new(
-                        "0".to_string(),
-                        vec![
-                            Value::test_string("bc"),
-                            Value::test_string("bc"),
-                            Value::test_string("bc"),
-                        ],
-                    )],
-                    None,
-                )
-                .expect("simple df for test should not fail")
-                .into_value(Span::test_data()),
-            ),
-        }]
+        vec![
+            Example {
+                description: "Creates slices from the strings",
+                example: "[abcded abc321 abc123] | dfr into-df | dfr str-slice 1 --length 2",
+                result: Some(
+                    NuDataFrame::try_from_columns(
+                        vec![Column::new(
+                            "0".to_string(),
+                            vec![
+                                Value::test_string("bc"),
+                                Value::test_string("bc"),
+                                Value::test_string("bc"),
+                            ],
+                        )],
+                        None,
+                    )
+                    .expect("simple df for test should not fail")
+                    .into_value(Span::test_data()),
+                ),
+            },
+            Example {
+                description: "Creates slices from the strings without length",
+                example: "[abcded abc321 abc123] | dfr into-df | dfr str-slice 1",
+                result: Some(
+                    NuDataFrame::try_from_columns(
+                        vec![Column::new(
+                            "0".to_string(),
+                            vec![
+                                Value::test_string("bcded"),
+                                Value::test_string("bc321"),
+                                Value::test_string("bc123"),
+                            ],
+                        )],
+                        None,
+                    )
+                    .expect("simple df for test should not fail")
+                    .into_value(Span::test_data()),
+                ),
+            },
+        ]
     }
 
     fn run(
@@ -71,9 +95,13 @@ fn command(
     input: PipelineData,
 ) -> Result<PipelineData, ShellError> {
     let start: i64 = call.req(engine_state, stack, 0)?;
+    let start = Series::new("", &[start]);
 
     let length: Option<i64> = call.get_flag(engine_state, stack, "length")?;
-    let length = length.map(|v| v as u64);
+    let length = match length {
+        Some(v) => Series::new("", &[v as u64]),
+        None => Series::new_null("", 1),
+    };
 
     let df = NuDataFrame::try_from_pipeline(input, call.head)?;
     let series = df.as_series(call.head)?;
@@ -86,8 +114,16 @@ fn command(
         inner: vec![],
     })?;
 
-    let mut res = chunked.str_slice(start, length);
-    res.rename(series.name());
+    let res = chunked
+        .str_slice(&start, &length)
+        .map_err(|e| ShellError::GenericError {
+            error: "Dataframe Error".into(),
+            msg: e.to_string(),
+            span: Some(call.head),
+            help: None,
+            inner: vec![],
+        })?
+        .with_name(series.name());
 
     NuDataFrame::try_from_series(vec![res.into_series()], call.head)
         .map(|df| PipelineData::Value(NuDataFrame::into_value(df, call.head), None))
