@@ -37,13 +37,16 @@ impl Command for StrFTime {
     let df = ([$dt $dt] | dfr into-df);
     $df | dfr strftime "%Y/%m/%d""#,
             result: Some(
-                NuDataFrame::try_from_columns(vec![Column::new(
-                    "0".to_string(),
-                    vec![
-                        Value::test_string("2020/08/04"),
-                        Value::test_string("2020/08/04"),
-                    ],
-                )])
+                NuDataFrame::try_from_columns(
+                    vec![Column::new(
+                        "0".to_string(),
+                        vec![
+                            Value::test_string("2020/08/04"),
+                            Value::test_string("2020/08/04"),
+                        ],
+                    )],
+                    None,
+                )
                 .expect("simple df for test should not fail")
                 .into_value(Span::test_data()),
             ),
