@@ -24,10 +24,10 @@ impl NuDataFrame {
         match right {
             Value::CustomValue { val: rhs, .. } => {
                 let rhs = rhs.as_any().downcast_ref::<NuDataFrame>().ok_or_else(|| {
-                    ShellError::DowncastNotPossible(
-                        "Unable to create dataframe".to_string(),
-                        rhs_span,
-                    )
+                    ShellError::DowncastNotPossible {
+                        msg: "Unable to create dataframe".to_string(),
+                        span: rhs_span,
+                    }
                 })?;
 
                 match (self.is_series(), rhs.is_series()) {
@@ -135,14 +135,12 @@ impl NuDataFrame {
                     })
                     .collect::<Vec<Series>>();
 
-                let df_new = DataFrame::new(new_cols).map_err(|e| {
-                    ShellError::GenericError(
-                        "Error creating dataframe".into(),
-                        e.to_string(),
-                        Some(span),
-                        None,
-                        Vec::new(),
-                    )
+                let df_new = DataFrame::new(new_cols).map_err(|e| ShellError::GenericError {
+                    error: "Error creating dataframe".into(),
+                    msg: e.to_string(),
+                    span: Some(span),
+                    help: None,
+                    inner: vec![],
                 })?;
 
                 Ok(NuDataFrame::new(false, df_new))
@@ -183,26 +181,24 @@ impl NuDataFrame {
                         match res {
                             Ok(s) => Ok(s.clone()),
                             Err(e) => Err({
-                                ShellError::GenericError(
-                                    "Error appending dataframe".into(),
-                                    format!("Unable to append: {e}"),
-                                    Some(span),
-                                    None,
-                                    Vec::new(),
-                                )
+                                ShellError::GenericError {
+                                    error: "Error appending dataframe".into(),
+                                    msg: format!("Unable to append: {e}"),
+                                    span: Some(span),
+                                    help: None,
+                                    inner: vec![],
+                                }
                             }),
                         }
                     })
                     .collect::<Result<Vec<Series>, ShellError>>()?;
 
-                let df_new = DataFrame::new(new_cols).map_err(|e| {
-                    ShellError::GenericError(
-                        "Error appending dataframe".into(),
-                        format!("Unable to append dataframes: {e}"),
-                        Some(span),
-                        None,
-                        Vec::new(),
-                    )
+                let df_new = DataFrame::new(new_cols).map_err(|e| ShellError::GenericError {
+                    error: "Error appending dataframe".into(),
+                    msg: format!("Unable to append dataframes: {e}"),
+                    span: Some(span),
+                    help: None,
+                    inner: vec![],
                 })?;
 
                 Ok(NuDataFrame::new(false, df_new))
