@@ -1,12 +1,27 @@
 use super::{get_input_num_type, get_number_bytes, InputNumType, NumberBytes};
+use itertools::Itertools;
+use nu_cmd_base::input_handler::{operate, CmdArgument};
 use nu_engine::CallExt;
 use nu_protocol::ast::Call;
+use nu_protocol::ast::CellPath;
 use nu_protocol::engine::{Command, EngineState, Stack};
+use nu_protocol::Spanned;
 use nu_protocol::{
-    Category, Example, PipelineData, ShellError, Signature, Span, Spanned, SyntaxShape, Type, Value,
+    Category, Example, PipelineData, ShellError, Signature, Span, SyntaxShape, Type, Value,
 };
-use num_traits::CheckedShr;
-use std::fmt::Display;
+use std::iter;
+
+struct Arguments {
+    signed: bool,
+    bits: usize,
+    number_size: NumberBytes,
+}
+
+impl CmdArgument for Arguments {
+    fn take_cell_paths(&mut self) -> Option<Vec<CellPath>> {
+        None
+    }
+}
 
 #[derive(Clone)]
 pub struct BitsShr;
@@ -20,11 +35,17 @@ impl Command for BitsShr {
         Signature::build("bits shr")
             .input_output_types(vec![
                 (Type::Int, Type::Int),
+                (Type::Binary, Type::Binary),
                 (
                     Type::List(Box::new(Type::Int)),
                     Type::List(Box::new(Type::Int)),
                 ),
+                (
+                    Type::List(Box::new(Type::Binary)),
+                    Type::List(Box::new(Type::Binary)),
+                ),
             ])
+            .allow_variants_without_examples(true)
             .required("bits", SyntaxShape::Int, "number of bits to shift right")
             .switch(
                 "signed",
@@ -33,7 +54,7 @@ impl Command for BitsShr {
             )
             .named(
                 "number-bytes",
-                SyntaxShape::String,
+                SyntaxShape::Int,
                 "the word size in number of bytes, it can be 1, 2, 4, 8, auto, default value `8`",
                 Some('n'),
             )
@@ -41,7 +62,7 @@ impl Command for BitsShr {
     }
 
     fn usage(&self) -> &str {
-        "Bitwise shift right for ints."
+        "Bitwise shift right for ints or binary values."
     }
 
     fn search_terms(&self) -> Vec<&str> {
@@ -58,27 +79,22 @@ impl Command for BitsShr {
         let head = call.head;
         let bits: usize = call.req(engine_state, stack, 0)?;
         let signed = call.has_flag(engine_state, stack, "signed")?;
-        let number_bytes: Option<Spanned<String>> =
+        let number_bytes: Option<Spanned<usize>> =
             call.get_flag(engine_state, stack, "number-bytes")?;
-        let bytes_len = get_number_bytes(number_bytes.as_ref());
-        if let NumberBytes::Invalid = bytes_len {
-            if let Some(val) = number_bytes {
-                return Err(ShellError::UnsupportedInput {
-                    msg: "Only 1, 2, 4, 8, or 'auto' bytes are supported as word sizes".to_string(),
-                    input: "value originates from here".to_string(),
-                    msg_span: head,
-                    input_span: val.span,
-                });
-            }
-        }
+        let number_size = get_number_bytes(number_bytes, head)?;
+
         // This doesn't match explicit nulls
         if matches!(input, PipelineData::Empty) {
             return Err(ShellError::PipelineEmpty { dst_span: head });
         }
-        input.map(
-            move |value| operate(value, bits, head, signed, bytes_len),
-            engine_state.ctrlc.clone(),
-        )
+
+        let args = Arguments {
+            signed,
+            number_size,
+            bits,
+        };
+
+        operate(action, args, input, head, engine_state.ctrlc.clone())
     }
 
     fn examples(&self) -> Vec<Example> {
@@ -96,75 +112,75 @@ impl Command for BitsShr {
                     Span::test_data(),
                 )),
             },
+            Example {
+                description: "Shift right a binary value",
+                example: "0x[4f f4] | bits shr 4",
+                result: Some(Value::binary(vec![0x04, 0xff], Span::test_data())),
+            },
         ]
     }
 }
 
-fn get_shift_right<T: CheckedShr + Display + Copy>(val: T, bits: u32, span: Span) -> Value
-where
-    i64: std::convert::TryFrom<T>,
-{
-    match val.checked_shr(bits) {
-        Some(val) => {
-            let shift_result = i64::try_from(val);
-            match shift_result {
-                Ok(val) => Value::int( val, span ),
-                Err(_) => Value::error(
-                    ShellError::GenericError {
-                        error: "Shift right result beyond the range of 64 bit signed number".into(),
-                        msg: format!(
-                            "{val} of the specified number of bytes shift right {bits} bits exceed limit"
-                        ),
-                        span: Some(span),
-                        help: None,
-                        inner: vec![],
-                    },
-                    span,
-                ),
-            }
-        }
-        None => Value::error(
-            ShellError::GenericError {
-                error: "Shift right failed".into(),
-                msg: format!("{val} shift right {bits} bits failed, you may shift too many bits"),
-                span: Some(span),
-                help: None,
-                inner: vec![],
-            },
-            span,
-        ),
-    }
-}
+fn action(input: &Value, args: &Arguments, span: Span) -> Value {
+    let Arguments {
+        signed,
+        number_size,
+        bits,
+    } = *args;
 
-fn operate(value: Value, bits: usize, head: Span, signed: bool, number_size: NumberBytes) -> Value {
-    let span = value.span();
-    match value {
+    match input {
         Value::Int { val, .. } => {
             use InputNumType::*;
-            // let bits = (((bits % 64) + 64) % 64) as u32;
+            let val = *val;
             let bits = bits as u32;
-            let input_type = get_input_num_type(val, signed, number_size);
-            match input_type {
-                One => get_shift_right(val as u8, bits, span),
-                Two => get_shift_right(val as u16, bits, span),
-                Four => get_shift_right(val as u32, bits, span),
-                Eight => get_shift_right(val as u64, bits, span),
-                SignedOne => get_shift_right(val as i8, bits, span),
-                SignedTwo => get_shift_right(val as i16, bits, span),
-                SignedFour => get_shift_right(val as i32, bits, span),
-                SignedEight => get_shift_right(val, bits, span),
-            }
+            let input_num_type = get_input_num_type(val, signed, number_size);
+
+            let int = match input_num_type {
+                One => ((val as u8) >> bits) as i64,
+                Two => ((val as u16) >> bits) as i64,
+                Four => ((val as u32) >> bits) as i64,
+                Eight => ((val as u64) >> bits) as i64,
+                SignedOne => ((val as i8) >> bits) as i64,
+                SignedTwo => ((val as i16) >> bits) as i64,
+                SignedFour => ((val as i32) >> bits) as i64,
+                SignedEight => val >> bits,
+            };
+
+            Value::int(int, span)
+        }
+        Value::Binary { val, .. } => {
+            let byte_shift = bits / 8;
+            let bit_shift = bits % 8;
+
+            let len = val.len();
+            use itertools::Position::*;
+            let bytes = iter::repeat(0)
+                .take(byte_shift)
+                .chain(
+                    val.iter()
+                        .copied()
+                        .circular_tuple_windows::<(u8, u8)>()
+                        .with_position()
+                        .map(|(pos, (lhs, rhs))| match pos {
+                            First | Only => lhs >> bit_shift,
+                            _ => (lhs >> bit_shift) | (rhs << bit_shift),
+                        })
+                        .take(len - byte_shift),
+                )
+                .collect::<Vec<u8>>();
+
+            Value::binary(bytes, span)
         }
         // Propagate errors by explicitly matching them before the final case.
-        Value::Error { .. } => value,
+        Value::Error { .. } => input.clone(),
         other => Value::error(
             ShellError::OnlySupportsThisInputType {
-                exp_input_type: "int".into(),
+                exp_input_type: "int or binary".into(),
                 wrong_type: other.get_type().to_string(),
-                dst_span: head,
+                dst_span: span,
                 src_span: other.span(),
             },
-            head,
+            span,
         ),
     }
 }
