@@ -104,7 +104,7 @@ impl Command for SubCommand {
 fn value_to_color(v: Option<Value>) -> Result<Option<Rgb>, ShellError> {
     let s = match v {
         None => return Ok(None),
-        Some(x) => x.as_string()?,
+        Some(x) => x.coerce_into_string()?,
     };
     Ok(Some(Rgb::from_hex_string(s)))
 }
