@@ -2,7 +2,7 @@ use heck::ToLowerCamelCase;
 use nu_protocol::ast::Call;
 use nu_protocol::engine::{Command, EngineState, Stack};
 use nu_protocol::{
-    Category, Example, PipelineData, Record, ShellError, Signature, Span, SyntaxShape, Type, Value,
+    record, Category, Example, PipelineData, ShellError, Signature, SyntaxShape, Type, Value,
 };
 
 use super::operate;
@@ -79,13 +79,10 @@ impl Command for SubCommand {
             Example {
                 description: "convert a column from a table to camelCase",
                 example: r#"[[lang, gems]; [nu_test, 100]] | str camel-case lang"#,
-                result: Some(Value::list(
-                    vec![Value::test_record(Record {
-                        cols: vec!["lang".to_string(), "gems".to_string()],
-                        vals: vec![Value::test_string("nuTest"), Value::test_int(100)],
-                    })],
-                    Span::test_data(),
-                )),
+                result: Some(Value::test_list(vec![Value::test_record(record! {
+                    "lang" => Value::test_string("nuTest"),
+                    "gems" => Value::test_int(100),
+                })])),
             },
         ]
     }
