@@ -75,7 +75,7 @@ impl Command for BytesAdd {
         let cell_paths: Vec<CellPath> = call.rest(engine_state, stack, 1)?;
         let cell_paths = (!cell_paths.is_empty()).then_some(cell_paths);
         let index: Option<usize> = call.get_flag(engine_state, stack, "index")?;
-        let end = call.has_flag("end");
+        let end = call.has_flag(engine_state, stack, "end")?;
 
         let arg = Arguments {
             added_data,
