@@ -3,5 +3,5 @@ pub mod sqlite;
 
 pub use sqlite::{
     convert_sqlite_row_to_nu_value, convert_sqlite_value_to_nu_value, open_connection_in_memory,
-    SQLiteDatabase,
+    open_connection_in_memory_custom, SQLiteDatabase, MEMORY_DB,
 };
