@@ -79,7 +79,7 @@ impl Command for Cd {
                     let oldpwd = stack.get_env_var(engine_state, "OLDPWD");
 
                     if let Some(oldpwd) = oldpwd {
-                        let path = oldpwd.as_path()?;
+                        let path = oldpwd.to_path()?;
                         let path = match nu_path::canonicalize_with(path.clone(), &cwd) {
                             Ok(p) => p,
                             Err(_) => {
@@ -229,7 +229,7 @@ fn have_permission(dir: impl AsRef<Path>) -> PermissionResult<'static> {
     }
 }
 
-#[cfg(any(target_os = "linux", target_os = "android"))]
+#[cfg(any(target_os = "linux", target_os = "freebsd", target_os = "android"))]
 fn any_group(_current_user_gid: gid_t, owner_group: u32) -> bool {
     use crate::filesystem::util::users;
     let Some(user_groups) = users::current_user_groups() else {
@@ -238,7 +238,10 @@ fn any_group(_current_user_gid: gid_t, owner_group: u32) -> bool {
     user_groups.iter().any(|gid| gid.as_raw() == owner_group)
 }
 
-#[cfg(all(unix, not(any(target_os = "linux", target_os = "android"))))]
+#[cfg(all(
+    unix,
+    not(any(target_os = "linux", target_os = "freebsd", target_os = "android"))
+))]
 fn any_group(current_user_gid: gid_t, owner_group: u32) -> bool {
     use crate::filesystem::util::users;
 
