@@ -1,11 +1,12 @@
+use super::util::get_rest_for_glob_pattern;
 use nu_engine::{current_dir, eval_block, CallExt};
 use nu_path::expand_to_real_path;
 use nu_protocol::ast::Call;
 use nu_protocol::engine::{Command, EngineState, Stack};
 use nu_protocol::util::BufferedReader;
 use nu_protocol::{
-    Category, DataSource, Example, IntoInterruptiblePipelineData, NuPath, PipelineData,
-    PipelineMetadata, RawStream, ShellError, Signature, Spanned, SyntaxShape, Type, Value,
+    Category, DataSource, Example, IntoInterruptiblePipelineData, NuGlob, PipelineData,
+    PipelineMetadata, RawStream, ShellError, Signature, Spanned, SyntaxShape, Type,
 };
 use std::io::BufReader;
 
@@ -42,11 +43,10 @@ impl Command for Open {
     fn signature(&self) -> nu_protocol::Signature {
         Signature::build("open")
             .input_output_types(vec![(Type::Nothing, Type::Any), (Type::String, Type::Any)])
-            .optional("filename", SyntaxShape::GlobPattern, "The filename to use.")
             .rest(
-                "filenames",
-                SyntaxShape::GlobPattern,
-                "Optional additional files to open.",
+                "files",
+                SyntaxShape::OneOf(vec![SyntaxShape::GlobPattern, SyntaxShape::String]),
+                "The file(s) to open.",
             )
             .switch("raw", "open file as raw binary", Some('r'))
             .category(Category::FileSystem)
@@ -63,22 +63,15 @@ impl Command for Open {
         let call_span = call.head;
         let ctrlc = engine_state.ctrlc.clone();
         let cwd = current_dir(engine_state, stack)?;
-        let req_path = call.opt::<Spanned<NuPath>>(engine_state, stack, 0)?;
-        let mut path_params = call.rest::<Spanned<NuPath>>(engine_state, stack, 1)?;
+        let mut paths = get_rest_for_glob_pattern(engine_state, stack, call, 0)?;
 
-        // FIXME: JT: what is this doing here?
-
-        if let Some(filename) = req_path {
-            path_params.insert(0, filename);
-        } else {
-            let filename = match input {
-                PipelineData::Value(Value::Nothing { .. }, ..) => {
-                    return Err(ShellError::MissingParameter {
-                        param_name: "needs filename".to_string(),
-                        span: call.head,
-                    })
+        if paths.is_empty() && call.rest_iter(0).next().is_none() {
+            // try to use path from pipeline input if there were no positional or spread args
+            let (filename, span) = match input {
+                PipelineData::Value(val, ..) => {
+                    let span = val.span();
+                    (val.coerce_into_string()?, span)
                 }
-                PipelineData::Value(val, ..) => val.as_spanned_string()?,
                 _ => {
                     return Err(ShellError::MissingParameter {
                         param_name: "needs filename".to_string(),
@@ -87,18 +80,15 @@ impl Command for Open {
                 }
             };
 
-            path_params.insert(
-                0,
-                Spanned {
-                    item: NuPath::UnQuoted(filename.item),
-                    span: filename.span,
-                },
-            );
+            paths.push(Spanned {
+                item: NuGlob::Expand(filename),
+                span,
+            });
         }
 
         let mut output = vec![];
 
-        for mut path in path_params.into_iter() {
+        for mut path in paths {
             //FIXME: `open` should not have to do this
             path.item = path.item.strip_ansi_string_unlikely();
 
@@ -107,7 +97,10 @@ impl Command for Open {
 
             for path in nu_engine::glob_from(&path, &cwd, call_span, None)
                 .map_err(|err| match err {
-                    ShellError::DirectoryNotFound { span, .. } => ShellError::FileNotFound { span },
+                    ShellError::DirectoryNotFound { span, .. } => ShellError::FileNotFound {
+                        file: path.item.to_string(),
+                        span,
+                    },
                     _ => err,
                 })?
                 .1
