@@ -14,19 +14,10 @@ impl Command for Compact {
 
     fn signature(&self) -> Signature {
         Signature::build("compact")
-            .input_output_types(vec![
-                (
-                    Type::List(Box::new(Type::Any)),
-                    Type::List(Box::new(Type::Any)),
-                ),
-                (Type::Table(vec![]), Type::Table(vec![])),
-                (
-                    // TODO: Should table be a subtype of List<Any>? If so then this
-                    // entry would be unnecessary.
-                    Type::Table(vec![]),
-                    Type::List(Box::new(Type::Any)),
-                ),
-            ])
+            .input_output_types(vec![(
+                Type::List(Box::new(Type::Any)),
+                Type::List(Box::new(Type::Any)),
+            )])
             .switch(
                 "empty",
                 "also compact empty items like \"\", {}, and []",
@@ -51,7 +42,7 @@ impl Command for Compact {
         call: &Call,
         input: PipelineData,
     ) -> Result<PipelineData, ShellError> {
-        let empty = call.has_flag("empty");
+        let empty = call.has_flag(engine_state, stack, "empty")?;
         compact(engine_state, stack, call, input, empty)
     }
 
