@@ -30,10 +30,7 @@ impl Command for Select {
             )
             .rest(
                 "rest",
-                SyntaxShape::OneOf(vec![
-                    SyntaxShape::CellPath,
-                    SyntaxShape::List(Box::new(SyntaxShape::CellPath)),
-                ]),
+                SyntaxShape::CellPath,
                 "The columns to select from the table.",
             )
             .allow_variants_without_examples(true)
@@ -69,44 +66,6 @@ produce a table, a list will produce a list, and a record will produce a record.
                 Value::CellPath { val, .. } => {
                     new_columns.push(val);
                 }
-                Value::List { vals, .. } => {
-                    for value in vals {
-                        let val_span = &value.span();
-                        match value {
-                            Value::String { val, .. } => {
-                                let cv = CellPath {
-                                    members: vec![PathMember::String {
-                                        val: val.clone(),
-                                        span: *val_span,
-                                        optional: false,
-                                    }],
-                                };
-                                new_columns.push(cv.clone());
-                            }
-                            Value::Int { val, .. } => {
-                                let cv = CellPath {
-                                    members: vec![PathMember::Int {
-                                        val: val as usize,
-                                        span: *val_span,
-                                        optional: false,
-                                    }],
-                                };
-                                new_columns.push(cv.clone());
-                            }
-                            Value::CellPath { val, .. } => {
-                                new_columns.push(val);
-                            }
-                            y => {
-                                return Err(ShellError::CantConvert {
-                                    to_type: "cell path".into(),
-                                    from_type: y.get_type().to_string(),
-                                    span: y.span(),
-                                    help: None,
-                                });
-                            }
-                        }
-                    }
-                }
                 Value::String { val, .. } => {
                     let cv = CellPath {
                         members: vec![PathMember::String {
@@ -178,23 +137,32 @@ produce a table, a list will produce a list, and a record will produce a record.
                 result: None,
             },
             Example {
-                description: "Select columns by a provided list of columns",
-                example: "let cols = [name type];[[name type size]; [Cargo.toml toml 1kb] [Cargo.lock toml 2kb]] | select $cols",
-                result: None
+                description: "Select multiple columns",
+                example: "[[name type size]; [Cargo.toml toml 1kb] [Cargo.lock toml 2kb]] | select name type",
+                result: Some(Value::test_list(vec![
+                    Value::test_record(record! {
+                        "name" => Value::test_string("Cargo.toml"),
+                        "type" => Value::test_string("toml"),
+                    }),
+                    Value::test_record(record! {
+                        "name" => Value::test_string("Cargo.lock"),
+                        "type" => Value::test_string("toml")
+                    }),
+                ]))
             },
             Example {
-                description: "Select columns by a provided list of columns",
-                example: r#"[[name type size]; [Cargo.toml toml 1kb] [Cargo.lock toml 2kb]] | select ["name", "type"]"#,
-                result: Some(Value::test_list(
-                    vec![
-                        Value::test_record(record! {"name" => Value::test_string("Cargo.toml"), "type" => Value::test_string("toml")}),
-                        Value::test_record(record! {"name" => Value::test_string("Cargo.lock"), "type" => Value::test_string("toml")})],
-                ))
-            },
-            Example {
-                description: "Select rows by a provided list of rows",
-                example: "let rows = [0 2];[[name type size]; [Cargo.toml toml 1kb] [Cargo.lock toml 2kb] [file.json json 3kb]] | select $rows",
-                result: None
+                description: "Select multiple columns by spreading a list",
+                example: r#"let cols = [name type]; [[name type size]; [Cargo.toml toml 1kb] [Cargo.lock toml 2kb]] | select ...$cols"#,
+                result: Some(Value::test_list(vec![
+                    Value::test_record(record! {
+                        "name" => Value::test_string("Cargo.toml"),
+                        "type" => Value::test_string("toml")
+                    }),
+                    Value::test_record(record! {
+                        "name" => Value::test_string("Cargo.lock"),
+                        "type" => Value::test_string("toml")
+                    }),
+                ]))
             },
         ]
     }
