@@ -193,7 +193,7 @@ fn sort_record(
             match &a.1 {
                 Value::String { val, .. } => val.clone(),
                 val => {
-                    if let Ok(val) = val.as_string() {
+                    if let Ok(val) = val.coerce_string() {
                         val
                     } else {
                         // Values that can't be turned to strings are disregarded by the sort
@@ -209,7 +209,7 @@ fn sort_record(
             match &b.1 {
                 Value::String { val, .. } => val.clone(),
                 val => {
-                    if let Ok(val) = val.as_string() {
+                    if let Ok(val) = val.coerce_string() {
                         val
                     } else {
                         // Values that can't be turned to strings are disregarded by the sort
@@ -275,7 +275,10 @@ pub fn sort(
                     };
 
                     if natural {
-                        match (folded_left.as_string(), folded_right.as_string()) {
+                        match (
+                            folded_left.coerce_into_string(),
+                            folded_right.coerce_into_string(),
+                        ) {
                             (Ok(left), Ok(right)) => compare_str(left, right),
                             _ => Ordering::Equal,
                         }
@@ -285,7 +288,7 @@ pub fn sort(
                             .unwrap_or(Ordering::Equal)
                     }
                 } else if natural {
-                    match (a.as_string(), b.as_string()) {
+                    match (a.coerce_str(), b.coerce_str()) {
                         (Ok(left), Ok(right)) => compare_str(left, right),
                         _ => Ordering::Equal,
                     }
@@ -334,7 +337,10 @@ pub fn process(
                 _ => right_res,
             };
             if natural {
-                match (folded_left.as_string(), folded_right.as_string()) {
+                match (
+                    folded_left.coerce_into_string(),
+                    folded_right.coerce_into_string(),
+                ) {
                     (Ok(left), Ok(right)) => compare_str(left, right),
                     _ => Ordering::Equal,
                 }
