@@ -193,8 +193,8 @@ pub fn transpose(
             if let Some(desc) = descs.first() {
                 match &i.get_data_by_key(desc) {
                     Some(x) => {
-                        if let Ok(s) = x.as_string() {
-                            headers.push(s.to_string());
+                        if let Ok(s) = x.coerce_string() {
+                            headers.push(s);
                         } else {
                             return Err(ShellError::GenericError {
                                 error: "Header row needs string headers".into(),
