@@ -1,3 +1,4 @@
+use chrono::SecondsFormat;
 use nu_protocol::ast::{Call, PathMember};
 use nu_protocol::engine::{Command, EngineState, Stack};
 use nu_protocol::{
@@ -51,12 +52,12 @@ fn helper(engine_state: &EngineState, v: &Value) -> Result<toml::Value, ShellErr
         Value::Int { val, .. } => toml::Value::Integer(*val),
         Value::Filesize { val, .. } => toml::Value::Integer(*val),
         Value::Duration { val, .. } => toml::Value::String(val.to_string()),
-        Value::Date { val, .. } => toml::Value::String(val.to_string()),
+        Value::Date { val, .. } => {
+            toml::Value::String(val.to_rfc3339_opts(SecondsFormat::AutoSi, false))
+        }
         Value::Range { .. } => toml::Value::String("<Range>".to_string()),
         Value::Float { val, .. } => toml::Value::Float(*val),
-        Value::String { val, .. } | Value::QuotedString { val, .. } => {
-            toml::Value::String(val.clone())
-        }
+        Value::String { val, .. } | Value::Glob { val, .. } => toml::Value::String(val.clone()),
         Value::Record { val, .. } => {
             let mut m = toml::map::Map::new();
             for (k, v) in val {
@@ -171,6 +172,7 @@ fn to_toml(
 #[cfg(test)]
 mod tests {
     use super::*;
+    use chrono::TimeZone;
 
     #[test]
     fn test_examples() {
@@ -179,6 +181,25 @@ mod tests {
         test_examples(ToToml {})
     }
 
+    #[test]
+    fn to_toml_creates_correct_date() {
+        let engine_state = EngineState::new();
+
+        let test_date = Value::date(
+            chrono::FixedOffset::east_opt(60 * 120)
+                .unwrap()
+                .with_ymd_and_hms(1980, 10, 12, 10, 12, 44)
+                .unwrap(),
+            Span::test_data(),
+        );
+
+        let reference_date = toml::Value::String(String::from("1980-10-12T10:12:44+02:00"));
+
+        let result = helper(&engine_state, &test_date);
+
+        assert!(result.is_ok_and(|res| res == reference_date));
+    }
+
     #[test]
     fn test_value_to_toml_value() {
         //
