@@ -52,7 +52,7 @@ pub fn value_to_yaml_value(v: &Value) -> Result<serde_yaml::Value, ShellError> {
         Value::Date { val, .. } => serde_yaml::Value::String(val.to_string()),
         Value::Range { .. } => serde_yaml::Value::Null,
         Value::Float { val, .. } => serde_yaml::Value::Number(serde_yaml::Number::from(*val)),
-        Value::String { val, .. } | Value::QuotedString { val, .. } => {
+        Value::String { val, .. } | Value::Glob { val, .. } => {
             serde_yaml::Value::String(val.clone())
         }
         Value::Record { val, .. } => {
