@@ -22,7 +22,9 @@ impl Command for SubCommand {
                 (Type::List(Box::new(Type::Number)), Type::Number),
                 (Type::List(Box::new(Type::Duration)), Type::Duration),
                 (Type::List(Box::new(Type::Filesize)), Type::Filesize),
+                (Type::Range, Type::Number),
                 (Type::Table(vec![]), Type::Record(vec![])),
+                (Type::Record(vec![]), Type::Record(vec![])),
             ])
             .allow_variants_without_examples(true)
             .category(Category::Math)
@@ -61,6 +63,11 @@ impl Command for SubCommand {
                     "b" => Value::test_int(3),
                 })),
             },
+            Example {
+                description: "Find the median of a list of file sizes",
+                example: "[5KB 10MB 200B] | math median",
+                result: Some(Value::test_filesize(5 * 1_000)),
+            },
         ]
     }
 }
