@@ -181,10 +181,10 @@ impl UrlComponents {
 
         if key == "params" {
             return match value {
-                Value::Record { ref val, .. } => {
+                Value::Record { val, .. } => {
                     let mut qs = val
-                        .iter()
-                        .map(|(k, v)| match v.as_string() {
+                        .into_iter()
+                        .map(|(k, v)| match v.coerce_into_string() {
                             Ok(val) => Ok(format!("{k}={val}")),
                             Err(err) => Err(err),
                         })
@@ -202,7 +202,7 @@ impl UrlComponents {
                             // if query is present it means that also query_span is set.
                             return Err(ShellError::IncompatibleParameters {
                                 left_message: format!("Mismatch, qs from params is: {qs}"),
-                                left_span: value.span(),
+                                left_span: value_span,
                                 right_message: format!("instead query is: {q}"),
                                 right_span: self.query_span.unwrap_or(Span::unknown()),
                             });
@@ -224,7 +224,7 @@ impl UrlComponents {
         }
 
         // apart from port and params all other keys are strings.
-        let s = value.as_string()?; // If value fails String conversion, just output this ShellError
+        let s = value.coerce_into_string()?; // If value fails String conversion, just output this ShellError
         if !Self::check_empty_string_ok(&key, &s, value_span)? {
             return Ok(self);
         }
@@ -259,7 +259,7 @@ impl UrlComponents {
                         // if query is present it means that also params_span is set.
                         return Err(ShellError::IncompatibleParameters {
                             left_message: format!("Mismatch, query param is: {s}"),
-                            left_span: value.span(),
+                            left_span: value_span,
                             right_message: format!("instead qs from params is: {q}"),
                             right_span: self.params_span.unwrap_or(Span::unknown()),
                         });
@@ -268,7 +268,7 @@ impl UrlComponents {
 
                 Ok(Self {
                     query: Some(format!("?{s}")),
-                    query_span: Some(value.span()),
+                    query_span: Some(value_span),
                     ..self
                 })
             }
