@@ -120,13 +120,13 @@ impl Command for SubCommand {
             },
             Example {
                 description: "Walk up two levels",
-                example: "'C:\\Users\\joe\\code\\test.txt' | path dirname -n 2",
+                example: "'C:\\Users\\joe\\code\\test.txt' | path dirname --num-levels 2",
                 result: Some(Value::test_string("C:\\Users\\joe")),
             },
             Example {
                 description: "Replace the part that would be returned with a custom path",
                 example:
-                    "'C:\\Users\\joe\\code\\test.txt' | path dirname -n 2 -r C:\\Users\\viking",
+                    "'C:\\Users\\joe\\code\\test.txt' | path dirname --num-levels 2 --replace C:\\Users\\viking",
                 result: Some(Value::test_string("C:\\Users\\viking\\code\\test.txt")),
             },
         ]
@@ -150,12 +150,13 @@ impl Command for SubCommand {
             },
             Example {
                 description: "Walk up two levels",
-                example: "'/home/joe/code/test.txt' | path dirname -n 2",
+                example: "'/home/joe/code/test.txt' | path dirname --num-levels 2",
                 result: Some(Value::test_string("/home/joe")),
             },
             Example {
                 description: "Replace the part that would be returned with a custom path",
-                example: "'/home/joe/code/test.txt' | path dirname -n 2 -r /home/viking",
+                example:
+                    "'/home/joe/code/test.txt' | path dirname --num-levels 2 --replace /home/viking",
                 result: Some(Value::test_string("/home/viking/code/test.txt")),
             },
         ]
