@@ -1,6 +1,6 @@
 use std::path::{Path, PathBuf};
 
-use nu_engine::{current_dir, current_dir_const};
+use nu_engine::{current_dir, current_dir_const, CallExt};
 use nu_path::expand_path_with;
 use nu_protocol::ast::Call;
 use nu_protocol::engine::{EngineState, Stack, StateWorkingSet};
@@ -12,6 +12,7 @@ use super::PathSubcommandArguments;
 
 struct Arguments {
     pwd: PathBuf,
+    not_follow_symlink: bool,
 }
 
 impl PathSubcommandArguments for Arguments {}
@@ -33,6 +34,7 @@ impl Command for SubCommand {
                     Type::List(Box::new(Type::Bool)),
                 ),
             ])
+            .switch("no-symlink", "Do not resolve symbolic links", Some('n'))
             .category(Category::Path)
     }
 
@@ -59,6 +61,7 @@ If you need to distinguish dirs and files, please use `path type`."#
         let head = call.head;
         let args = Arguments {
             pwd: current_dir(engine_state, stack)?,
+            not_follow_symlink: call.has_flag(engine_state, stack, "no-symlink")?,
         };
         // This doesn't match explicit nulls
         if matches!(input, PipelineData::Empty) {
@@ -79,6 +82,7 @@ If you need to distinguish dirs and files, please use `path type`."#
         let head = call.head;
         let args = Arguments {
             pwd: current_dir_const(working_set)?,
+            not_follow_symlink: call.has_flag_const(working_set, "no-symlink")?,
         };
         // This doesn't match explicit nulls
         if matches!(input, PipelineData::Empty) {
@@ -130,9 +134,26 @@ If you need to distinguish dirs and files, please use `path type`."#
 }
 
 fn exists(path: &Path, span: Span, args: &Arguments) -> Value {
+    if path.as_os_str().is_empty() {
+        return Value::bool(false, span);
+    }
     let path = expand_path_with(path, &args.pwd);
+    let exists = if args.not_follow_symlink {
+        // symlink_metadata returns true if the file/folder exists
+        // whether it is a symbolic link or not. Sorry, but returns Err
+        // in every other scenario including the NotFound
+        std::fs::symlink_metadata(path).map_or_else(
+            |e| match e.kind() {
+                std::io::ErrorKind::NotFound => Ok(false),
+                _ => Err(e),
+            },
+            |_| Ok(true),
+        )
+    } else {
+        path.try_exists()
+    };
     Value::bool(
-        match path.try_exists() {
+        match exists {
             Ok(exists) => exists,
             Err(err) => {
                 return Value::error(
