@@ -199,10 +199,10 @@ impl Command for SubCommand {
         input.map(
             move |v| {
                 let value_span = v.span();
-                match v.as_string() {
+                match v.coerce_into_string() {
                     Ok(s) => {
                         let contents = if is_path { s.replace('\\', "\\\\") } else { s };
-                        str_expand(&contents, span, v.span())
+                        str_expand(&contents, span, value_span)
                     }
                     Err(_) => Value::error(
                         ShellError::PipelineMismatch {
