@@ -100,7 +100,7 @@ fn stats(
                 return Value::error(*error, span);
             }
             // Now, check if it's a string.
-            match v.as_string() {
+            match v.coerce_into_string() {
                 Ok(s) => counter(&s, span),
                 Err(_) => Value::error(
                     ShellError::PipelineMismatch {
