@@ -13,6 +13,7 @@ mod config_nu_default;
 mod continue_;
 mod conversions;
 mod cp;
+#[cfg(feature = "sqlite")]
 mod database;
 mod date;
 mod debug_info;
@@ -21,6 +22,7 @@ mod default;
 mod detect_columns;
 mod do_;
 mod drop;
+mod du;
 mod each;
 mod echo;
 mod empty;
@@ -45,6 +47,7 @@ mod help;
 mod histogram;
 mod insert;
 mod inspect;
+mod interleave;
 mod into_datetime;
 mod into_filesize;
 mod into_int;
@@ -58,7 +61,6 @@ mod ls;
 mod match_;
 mod math;
 mod merge;
-mod mkdir;
 mod mktemp;
 mod move_;
 mod mut_;
@@ -92,6 +94,7 @@ mod select;
 mod semicolon;
 mod seq;
 mod seq_char;
+mod seq_date;
 mod skip;
 mod sort;
 mod sort_by;
@@ -102,6 +105,7 @@ mod split_row;
 mod str_;
 mod table;
 mod take;
+mod tee;
 mod terminal;
 mod to_text;
 mod touch;
