@@ -15,7 +15,7 @@ fn moves_a_file() {
 
         nu!(
             cwd: dirs.test(),
-            "umv andres.txt expected/yehuda.txt"
+            "mv andres.txt expected/yehuda.txt"
         );
 
         assert!(!original.exists());
@@ -33,7 +33,7 @@ fn overwrites_if_moving_to_existing_file_and_force_provided() {
 
         nu!(
             cwd: dirs.test(),
-            "umv andres.txt -f jttxt"
+            "mv andres.txt -f jttxt"
         );
 
         assert!(!original.exists());
@@ -51,7 +51,7 @@ fn moves_a_directory() {
 
         nu!(
             cwd: dirs.test(),
-            "umv empty_dir renamed_dir"
+            "mv empty_dir renamed_dir"
         );
 
         assert!(!original_dir.exists());
@@ -71,7 +71,7 @@ fn moves_the_file_inside_directory_if_path_to_move_is_existing_directory() {
 
         nu!(
             cwd: dirs.test(),
-            "umv jttxt expected"
+            "mv jttxt expected"
         );
 
         assert!(!original_dir.exists());
@@ -92,7 +92,7 @@ fn moves_the_directory_inside_directory_if_path_to_move_is_existing_directory()
 
         nu!(
             cwd: dirs.test(),
-            "umv contributors expected"
+            "mv contributors expected"
         );
 
         assert!(!original_dir.exists());
@@ -123,7 +123,7 @@ fn moves_using_path_with_wildcard() {
         let work_dir = dirs.test().join("work_dir");
         let expected = dirs.test().join("expected");
 
-        nu!(cwd: work_dir, "umv ../originals/*.ini ../expected");
+        nu!(cwd: work_dir, "mv ../originals/*.ini ../expected");
 
         assert!(files_exist_at(
             vec!["yehuda.ini", "jt.ini", "sample.ini", "andres.ini",],
@@ -149,7 +149,7 @@ fn moves_using_a_glob() {
         let work_dir = dirs.test().join("work_dir");
         let expected = dirs.test().join("expected");
 
-        nu!(cwd: work_dir, "umv ../meals/* ../expected");
+        nu!(cwd: work_dir, "mv ../meals/* ../expected");
 
         assert!(meal_dir.exists());
         assert!(files_exist_at(
@@ -179,7 +179,7 @@ fn moves_a_directory_with_files() {
 
         nu!(
             cwd: dirs.test(),
-            "umv vehicles expected"
+            "mv vehicles expected"
         );
 
         assert!(!original_dir.exists());
@@ -202,7 +202,7 @@ fn errors_if_source_doesnt_exist() {
         sandbox.mkdir("test_folder");
         let actual = nu!(
             cwd: dirs.test(),
-            "umv non-existing-file test_folder/"
+            "mv non-existing-file test_folder/"
         );
         assert!(actual.err.contains("Directory not found"));
     })
@@ -216,7 +216,7 @@ fn error_if_moving_to_existing_file_without_force() {
 
         let actual = nu!(
             cwd: dirs.test(),
-            "umv andres.txt jttxt"
+            "mv andres.txt jttxt"
         );
         assert!(actual.err.contains("file already exists"))
     })
@@ -229,7 +229,7 @@ fn errors_if_destination_doesnt_exist() {
 
         let actual = nu!(
             cwd: dirs.test(),
-            "umv empty.txt does/not/exist/"
+            "mv empty.txt does/not/exist/"
         );
 
         assert!(actual.err.contains("failed to access"));
@@ -248,7 +248,7 @@ fn errors_if_multiple_sources_but_destination_not_a_directory() {
 
         let actual = nu!(
             cwd: dirs.test(),
-            "umv file?.txt not_a_dir"
+            "mv file?.txt not_a_dir"
         );
 
         assert!(actual
@@ -266,7 +266,7 @@ fn errors_if_renaming_directory_to_an_existing_file() {
 
         let actual = nu!(
             cwd: dirs.test(),
-            "umv mydir empty.txt"
+            "mv mydir empty.txt"
         );
         assert!(actual.err.contains("cannot overwrite non-directory"),);
         assert!(actual.err.contains("with directory"),);
@@ -280,7 +280,7 @@ fn errors_if_moving_to_itself() {
 
         let actual = nu!(
             cwd: dirs.test(),
-            "umv mydir mydir/mydir_2/"
+            "mv mydir mydir/mydir_2/"
         );
         assert!(actual.err.contains("cannot move"));
         assert!(actual.err.contains("to a subdirectory"));
@@ -299,7 +299,7 @@ fn does_not_error_on_relative_parent_path() {
 
         nu!(
             cwd: dirs.test().join("first"),
-            "umv william_hartnell.txt ./.."
+            "mv william_hartnell.txt ./.."
         );
 
         assert!(!original.exists());
@@ -321,7 +321,7 @@ fn move_files_using_glob_two_parents_up_using_multiple_dots() {
         nu!(
             cwd: dirs.test().join("foo/bar"),
             r#"
-                umv * ...
+                mv * ...
             "#
         );
 
@@ -350,7 +350,7 @@ fn move_file_from_two_parents_up_using_multiple_dots_to_current_dir() {
         nu!(
             cwd: dirs.test().join("foo/bar"),
             r#"
-                umv .../hello_there .
+                mv .../hello_there .
             "#
         );
 
@@ -369,7 +369,7 @@ fn does_not_error_when_some_file_is_moving_into_itself() {
 
         let original_dir = dirs.test().join("11");
         let expected = dirs.test().join("12/11");
-        nu!(cwd: dirs.test(), "umv 1* 12");
+        nu!(cwd: dirs.test(), "mv 1* 12");
 
         assert!(!original_dir.exists());
         assert!(expected.exists());
@@ -383,7 +383,7 @@ fn mv_ignores_ansi() {
         let actual = nu!(
              cwd: sandbox.cwd(),
             r#"
-                 ls | find test | umv $in.0.name success.txt; ls | $in.0.name
+                 ls | find test | mv $in.0.name success.txt; ls | $in.0.name
             "#
         );
 
@@ -401,7 +401,7 @@ fn mv_directory_with_same_name() {
         let actual = nu!(
             cwd: cwd,
             r#"
-                 umv testdir ..
+                 mv testdir ..
             "#
         );
         assert!(actual.err.contains("Directory not empty"));
@@ -426,7 +426,7 @@ fn mv_change_case_of_directory() {
 
         let _actual = nu!(
             cwd: dirs.test(),
-            format!("umv {original_dir} {new_dir}")
+            format!("mv {original_dir} {new_dir}")
         );
 
         // Doing this instead of `Path::exists()` because we need to check file existence in
@@ -436,19 +436,19 @@ fn mv_change_case_of_directory() {
             .map(|de| de.unwrap().file_name().to_string_lossy().into_owned())
             .collect();
 
-        #[cfg(target_os = "linux")]
+        #[cfg(any(target_os = "linux", target_os = "freebsd"))]
         assert!(
             !_files_in_test_directory.contains(&original_dir)
                 && _files_in_test_directory.contains(&new_dir)
         );
 
-        #[cfg(target_os = "linux")]
+        #[cfg(any(target_os = "linux", target_os = "freebsd"))]
         assert!(files_exist_at(
             vec!["somefile.txt",],
             dirs.test().join(new_dir)
         ));
 
-        #[cfg(not(target_os = "linux"))]
+        #[cfg(not(any(target_os = "linux", target_os = "freebsd")))]
         _actual.err.contains("to a subdirectory of itself");
     })
 }
@@ -465,7 +465,7 @@ fn mv_change_case_of_file() {
 
         let _actual = nu!(
             cwd: dirs.test(),
-            format!("umv {original_file_name} -f {new_file_name}")
+            format!("mv {original_file_name} -f {new_file_name}")
         );
 
         // Doing this instead of `Path::exists()` because we need to check file existence in
@@ -474,12 +474,12 @@ fn mv_change_case_of_file() {
             .unwrap()
             .map(|de| de.unwrap().file_name().to_string_lossy().into_owned())
             .collect();
-        #[cfg(target_os = "linux")]
+        #[cfg(any(target_os = "linux", target_os = "freebsd"))]
         assert!(
             !_files_in_test_directory.contains(&original_file_name)
                 && _files_in_test_directory.contains(&new_file_name)
         );
-        #[cfg(not(target_os = "linux"))]
+        #[cfg(not(any(target_os = "linux", target_os = "freebsd")))]
         _actual.err.contains("are the same file");
     })
 }
@@ -487,7 +487,7 @@ fn mv_change_case_of_file() {
 #[test]
 #[ignore = "Update not supported..remove later"]
 fn mv_with_update_flag() {
-    Playground::setup("mv_with_update_flag", |_dirs, sandbox| {
+    Playground::setup("umv_with_update_flag", |_dirs, sandbox| {
         sandbox.with_files(vec![
             EmptyFile("valid.txt"),
             FileWithContent("newer_valid.txt", "body"),
@@ -495,19 +495,19 @@ fn mv_with_update_flag() {
 
         let actual = nu!(
             cwd: sandbox.cwd(),
-            "umv -uf valid.txt newer_valid.txt; open newer_valid.txt",
+            "mv -uf valid.txt newer_valid.txt; open newer_valid.txt",
         );
         assert_eq!(actual.out, "body");
 
         // create a file after assert to make sure that newest_valid.txt is newest
         std::thread::sleep(std::time::Duration::from_secs(1));
         sandbox.with_files(vec![FileWithContent("newest_valid.txt", "newest_body")]);
-        let actual = nu!(cwd: sandbox.cwd(), "umv -uf newest_valid.txt valid.txt; open valid.txt");
+        let actual = nu!(cwd: sandbox.cwd(), "mv -uf newest_valid.txt valid.txt; open valid.txt");
         assert_eq!(actual.out, "newest_body");
 
         // when destination doesn't exist
         sandbox.with_files(vec![FileWithContent("newest_valid.txt", "newest_body")]);
-        let actual = nu!(cwd: sandbox.cwd(), "umv -uf newest_valid.txt des_missing.txt; open des_missing.txt");
+        let actual = nu!(cwd: sandbox.cwd(), "mv -uf newest_valid.txt des_missing.txt; open des_missing.txt");
         assert_eq!(actual.out, "newest_body");
     });
 }
@@ -522,7 +522,7 @@ fn test_mv_no_clobber() {
 
         let actual = nu!(
             cwd: dirs.test(),
-            "umv -n {} {}",
+            "mv -n {} {}",
             file_a,
             file_b,
         );
@@ -535,7 +535,7 @@ fn mv_with_no_arguments() {
     Playground::setup("umv_test_14", |dirs, _| {
         let actual = nu!(
             cwd: dirs.test(),
-            "umv",
+            "mv",
         );
         assert!(actual.err.contains("Missing file operand"));
     })
@@ -546,7 +546,7 @@ fn mv_with_no_target() {
     Playground::setup("umv_test_15", |dirs, _| {
         let actual = nu!(
             cwd: dirs.test(),
-            "umv a",
+            "mv a",
         );
         assert!(actual.err.contains(
             format!(
@@ -574,7 +574,33 @@ fn mv_files_with_glob_metachars(#[case] src_name: &str) {
 
         let actual = nu!(
             cwd: dirs.test(),
-            "umv '{}' {}",
+            "mv '{}' {}",
+            src.display(),
+            "hello_world_dest"
+        );
+
+        assert!(actual.err.is_empty());
+        assert!(dirs.test().join("hello_world_dest").exists());
+    });
+}
+
+#[rstest]
+#[case("a]c")]
+#[case("a[c")]
+#[case("a[bc]d")]
+#[case("a][c")]
+fn mv_files_with_glob_metachars_when_input_are_variables(#[case] src_name: &str) {
+    Playground::setup("umv_test_18", |dirs, sandbox| {
+        sandbox.with_files(vec![FileWithContent(
+            src_name,
+            "What is the sound of one hand clapping?",
+        )]);
+
+        let src = dirs.test().join(src_name);
+
+        let actual = nu!(
+            cwd: dirs.test(),
+            "let f = '{}'; mv $f {}",
             src.display(),
             "hello_world_dest"
         );
@@ -591,6 +617,7 @@ fn mv_files_with_glob_metachars(#[case] src_name: &str) {
 // windows doesn't allow filename with `*`.
 fn mv_files_with_glob_metachars_nw(#[case] src_name: &str) {
     mv_files_with_glob_metachars(src_name);
+    mv_files_with_glob_metachars_when_input_are_variables(src_name);
 }
 
 #[test]
@@ -602,7 +629,7 @@ fn mv_with_cd() {
 
         let actual = nu!(
             cwd: sandbox.cwd(),
-            r#"do { cd tmp_dir; let f = 'file.txt'; umv $f .. }; open file.txt"#,
+            r#"do { cd tmp_dir; let f = 'file.txt'; mv $f .. }; open file.txt"#,
         );
         assert!(actual.out.contains("body"));
     });
