@@ -29,7 +29,7 @@ fn trims() {
 fn error_trim_multiple_chars() {
     let actual = nu!(pipeline(
         r#"
-        echo "does it work now?!" | str trim -c "?!"
+        echo "does it work now?!" | str trim --char "?!"
         "#
     ));
 
@@ -76,6 +76,13 @@ fn downcases() {
     })
 }
 
+#[test]
+fn non_ascii_downcase() {
+    let actual = nu!("'ὈΔΥΣΣΕΎΣ' | str downcase");
+
+    assert_eq!(actual.out, "ὀδυσσεύς");
+}
+
 #[test]
 fn upcases() {
     Playground::setup("str_test_4", |dirs, sandbox| {
@@ -96,6 +103,13 @@ fn upcases() {
     })
 }
 
+#[test]
+fn non_ascii_upcase() {
+    let actual = nu!("'ὀδυσσεύς' | str upcase");
+
+    assert_eq!(actual.out, "ὈΔΥΣΣΕΎΣ");
+}
+
 #[test]
 #[ignore = "Playgrounds are not supported in nu-cmd-extra"]
 fn camelcases() {
