@@ -5,10 +5,10 @@ use std::path::Path;
 
 #[test]
 fn creates_directory() {
-    Playground::setup("umkdir_test_1", |dirs, _| {
+    Playground::setup("mkdir_test_1", |dirs, _| {
         nu!(
             cwd: dirs.test(),
-            "umkdir my_new_directory"
+            "mkdir my_new_directory"
         );
 
         let expected = dirs.test().join("my_new_directory");
@@ -19,10 +19,10 @@ fn creates_directory() {
 
 #[test]
 fn accepts_and_creates_directories() {
-    Playground::setup("umkdir_test_2", |dirs, _| {
+    Playground::setup("mkdir_test_2", |dirs, _| {
         nu!(
             cwd: dirs.test(),
-            "umkdir dir_1 dir_2 dir_3"
+            "mkdir dir_1 dir_2 dir_3"
         );
 
         assert!(files_exist_at(
@@ -34,10 +34,10 @@ fn accepts_and_creates_directories() {
 
 #[test]
 fn creates_intermediary_directories() {
-    Playground::setup("umkdir_test_3", |dirs, _| {
+    Playground::setup("mkdir_test_3", |dirs, _| {
         nu!(
             cwd: dirs.test(),
-            "umkdir some_folder/another/deeper_one"
+            "mkdir some_folder/another/deeper_one"
         );
 
         let expected = dirs.test().join("some_folder/another/deeper_one");
@@ -48,12 +48,12 @@ fn creates_intermediary_directories() {
 
 #[test]
 fn create_directory_two_parents_up_using_multiple_dots() {
-    Playground::setup("umkdir_test_4", |dirs, sandbox| {
+    Playground::setup("mkdir_test_4", |dirs, sandbox| {
         sandbox.within("foo").mkdir("bar");
 
         nu!(
             cwd: dirs.test().join("foo/bar"),
-            "umkdir .../boo"
+            "mkdir .../boo"
         );
 
         let expected = dirs.test().join("boo");
@@ -64,10 +64,10 @@ fn create_directory_two_parents_up_using_multiple_dots() {
 
 #[test]
 fn print_created_paths() {
-    Playground::setup("umkdir_test_2", |dirs, _| {
+    Playground::setup("mkdir_test_2", |dirs, _| {
         let actual = nu!(
             cwd: dirs.test(),
-            pipeline("umkdir -v dir_1 dir_2 dir_3")
+            pipeline("mkdir -v dir_1 dir_2 dir_3")
         );
 
         assert!(files_exist_at(
@@ -83,10 +83,10 @@ fn print_created_paths() {
 
 #[test]
 fn creates_directory_three_dots() {
-    Playground::setup("umkdir_test_1", |dirs, _| {
+    Playground::setup("mkdir_test_1", |dirs, _| {
         nu!(
             cwd: dirs.test(),
-            "umkdir test..."
+            "mkdir test..."
         );
 
         let expected = dirs.test().join("test...");
@@ -97,10 +97,10 @@ fn creates_directory_three_dots() {
 
 #[test]
 fn creates_directory_four_dots() {
-    Playground::setup("umkdir_test_1", |dirs, _| {
+    Playground::setup("mkdir_test_1", |dirs, _| {
         nu!(
             cwd: dirs.test(),
-            "umkdir test...."
+            "mkdir test...."
         );
 
         let expected = dirs.test().join("test....");
@@ -111,10 +111,10 @@ fn creates_directory_four_dots() {
 
 #[test]
 fn creates_directory_three_dots_quotation_marks() {
-    Playground::setup("umkdir_test_1", |dirs, _| {
+    Playground::setup("mkdir_test_1", |dirs, _| {
         nu!(
             cwd: dirs.test(),
-            "umkdir 'test...'"
+            "mkdir 'test...'"
         );
 
         let expected = dirs.test().join("test...");
