@@ -86,7 +86,7 @@ impl ViewCommand for NuCmd {
         let (columns, values) = collect_pipeline(pipeline);
 
         if let Some(value) = has_simple_value(&values) {
-            let text = value.into_abbreviated_string(&engine_state.config);
+            let text = value.to_abbreviated_string(&engine_state.config);
             return Ok(NuView::Preview(Preview::new(&text)));
         }
 
