@@ -1,5 +1,5 @@
 use nu_protocol::{
-    ast::{Expr, Expression, MatchPattern, Pattern},
+    ast::{MatchPattern, Pattern},
     engine::StateWorkingSet,
     ParseError, Span, SyntaxShape, Type, VarId,
 };
@@ -18,19 +18,6 @@ pub fn garbage(span: Span) -> MatchPattern {
     }
 }
 
-pub fn parse_match_pattern(working_set: &mut StateWorkingSet, span: Span) -> Expression {
-    working_set.enter_scope();
-    let output = parse_pattern(working_set, span);
-    working_set.exit_scope();
-
-    Expression {
-        expr: Expr::MatchPattern(Box::new(output)),
-        span,
-        ty: Type::Any,
-        custom_completion: None,
-    }
-}
-
 pub fn parse_pattern(working_set: &mut StateWorkingSet, span: Span) -> MatchPattern {
     let bytes = working_set.get_span_contents(span);
 
