@@ -15,7 +15,7 @@
 //! function, which will handle all of the input and output serialization when
 //! invoked by Nushell.
 //!
-//! ```
+//! ```rust,no_run
 //! use nu_plugin::{EvaluatedCall, LabeledError, MsgPackSerializer, Plugin, serve_plugin};
 //! use nu_protocol::{PluginSignature, Value};
 //!
@@ -46,8 +46,21 @@
 //! that demonstrates the full range of plugin capabilities.
 mod plugin;
 mod protocol;
+mod sequence;
 mod serializers;
 
-pub use plugin::{get_signature, serve_plugin, Plugin, PluginDeclaration};
-pub use protocol::{EvaluatedCall, LabeledError, PluginResponse};
-pub use serializers::{json::JsonSerializer, msgpack::MsgPackSerializer, EncodingType};
+pub use plugin::{serve_plugin, Plugin, PluginEncoder, StreamingPlugin};
+pub use protocol::{EvaluatedCall, LabeledError};
+pub use serializers::{json::JsonSerializer, msgpack::MsgPackSerializer};
+
+// Used by other nu crates.
+#[doc(hidden)]
+pub use plugin::{get_signature, PluginDeclaration};
+#[doc(hidden)]
+pub use serializers::EncodingType;
+
+// Used by external benchmarks.
+#[doc(hidden)]
+pub use plugin::Encoder;
+#[doc(hidden)]
+pub use protocol::{PluginCallResponse, PluginOutput};
