@@ -1,6 +1,5 @@
 use crate::{ast::Expression, engine::StateWorkingSet, Span};
 use serde::{Deserialize, Serialize};
-use std::ops::{Index, IndexMut};
 
 #[derive(Debug, Clone, Serialize, Deserialize, Eq, PartialEq)]
 pub enum Redirection {
@@ -13,6 +12,8 @@ pub enum Redirection {
 #[derive(Debug, Clone, Serialize, Deserialize)]
 pub enum PipelineElement {
     Expression(Option<Span>, Expression),
+    ErrPipedExpression(Option<Span>, Expression),
+    OutErrPipedExpression(Option<Span>, Expression),
     // final field indicates if it's in append mode
     Redirection(Span, Redirection, Expression, bool),
     // final bool field indicates if it's in append mode
@@ -32,7 +33,9 @@ pub enum PipelineElement {
 impl PipelineElement {
     pub fn expression(&self) -> &Expression {
         match self {
-            PipelineElement::Expression(_, expression) => expression,
+            PipelineElement::Expression(_, expression)
+            | PipelineElement::ErrPipedExpression(_, expression)
+            | PipelineElement::OutErrPipedExpression(_, expression) => expression,
             PipelineElement::Redirection(_, _, expression, _) => expression,
             PipelineElement::SeparateRedirection {
                 out: (_, expression, _),
@@ -50,11 +53,15 @@ impl PipelineElement {
     pub fn span(&self) -> Span {
         match self {
             PipelineElement::Expression(None, expression)
+            | PipelineElement::ErrPipedExpression(None, expression)
+            | PipelineElement::OutErrPipedExpression(None, expression)
             | PipelineElement::SameTargetRedirection {
                 cmd: (None, expression),
                 ..
             } => expression.span,
             PipelineElement::Expression(Some(span), expression)
+            | PipelineElement::ErrPipedExpression(Some(span), expression)
+            | PipelineElement::OutErrPipedExpression(Some(span), expression)
             | PipelineElement::Redirection(span, _, expression, _)
             | PipelineElement::SeparateRedirection {
                 out: (span, expression, _),
@@ -74,6 +81,8 @@ impl PipelineElement {
     pub fn has_in_variable(&self, working_set: &StateWorkingSet) -> bool {
         match self {
             PipelineElement::Expression(_, expression)
+            | PipelineElement::ErrPipedExpression(_, expression)
+            | PipelineElement::OutErrPipedExpression(_, expression)
             | PipelineElement::Redirection(_, _, expression, _)
             | PipelineElement::And(_, expression)
             | PipelineElement::Or(_, expression)
@@ -96,6 +105,8 @@ impl PipelineElement {
     ) {
         match self {
             PipelineElement::Expression(_, expression)
+            | PipelineElement::ErrPipedExpression(_, expression)
+            | PipelineElement::OutErrPipedExpression(_, expression)
             | PipelineElement::Redirection(_, _, expression, _)
             | PipelineElement::And(_, expression)
             | PipelineElement::Or(_, expression)
@@ -147,17 +158,3 @@ impl Pipeline {
         self.elements.is_empty()
     }
 }
-
-impl Index<usize> for Pipeline {
-    type Output = PipelineElement;
-
-    fn index(&self, index: usize) -> &Self::Output {
-        &self.elements[index]
-    }
-}
-
-impl IndexMut<usize> for Pipeline {
-    fn index_mut(&mut self, index: usize) -> &mut Self::Output {
-        &mut self.elements[index]
-    }
-}
