@@ -2,7 +2,9 @@ use miette::Diagnostic;
 use serde::{Deserialize, Serialize};
 use thiserror::Error;
 
-use crate::{ast::Operator, engine::StateWorkingSet, format_error, ParseError, Span, Value};
+use crate::{
+    ast::Operator, engine::StateWorkingSet, format_error, ParseError, Span, Spanned, Value,
+};
 
 /// The fundamental error type for the evaluation engine. These cases represent different kinds of errors
 /// the evaluator might face, along with helpful spans to label. An error renderer will take this error value
@@ -727,8 +729,9 @@ pub enum ShellError {
     ///
     /// Does the file in the error message exist? Is it readable and accessible? Is the casing right?
     #[error("File not found")]
-    #[diagnostic(code(nu::shell::file_not_found))]
+    #[diagnostic(code(nu::shell::file_not_found), help("{file} does not exist"))]
     FileNotFound {
+        file: String,
         #[label("file not found")]
         span: Span,
     },
@@ -773,6 +776,54 @@ pub enum ShellError {
     #[diagnostic(code(nu::shell::plugin_failed_to_decode))]
     PluginFailedToDecode { msg: String },
 
+    /// A custom value cannot be sent to the given plugin.
+    ///
+    /// ## Resolution
+    ///
+    /// Custom values can only be used with the plugin they came from. Use a command from that
+    /// plugin instead.
+    #[error("Custom value `{name}` cannot be sent to plugin")]
+    #[diagnostic(code(nu::shell::custom_value_incorrect_for_plugin))]
+    CustomValueIncorrectForPlugin {
+        name: String,
+        #[label("the `{dest_plugin}` plugin does not support this kind of value")]
+        span: Span,
+        dest_plugin: String,
+        #[help("this value came from the `{}` plugin")]
+        src_plugin: Option<String>,
+    },
+
+    /// The plugin failed to encode a custom value.
+    ///
+    /// ## Resolution
+    ///
+    /// This is likely a bug with the plugin itself. The plugin may have tried to send a custom
+    /// value that is not serializable.
+    #[error("Custom value failed to encode")]
+    #[diagnostic(code(nu::shell::custom_value_failed_to_encode))]
+    CustomValueFailedToEncode {
+        msg: String,
+        #[label("{msg}")]
+        span: Span,
+    },
+
+    /// The plugin failed to encode a custom value.
+    ///
+    /// ## Resolution
+    ///
+    /// This may be a bug within the plugin, or the plugin may have been updated in between the
+    /// creation of the custom value and its use.
+    #[error("Custom value failed to decode")]
+    #[diagnostic(code(nu::shell::custom_value_failed_to_decode))]
+    #[diagnostic(help(
+        "the plugin may have been updated and no longer support this custom value"
+    ))]
+    CustomValueFailedToDecode {
+        msg: String,
+        #[label("{msg}")]
+        span: Span,
+    },
+
     /// I/O operation interrupted.
     ///
     /// ## Resolution
@@ -808,32 +859,6 @@ pub enum ShellError {
         span: Span,
     },
 
-    /// Permission for an operation was denied.
-    ///
-    /// ## Resolution
-    ///
-    /// This is a generic error. Refer to the specific error message for further details.
-    #[error("Permission Denied")]
-    #[diagnostic(code(nu::shell::permission_denied))]
-    PermissionDeniedError {
-        msg: String,
-        #[label("{msg}")]
-        span: Span,
-    },
-
-    /// Out of memory.
-    ///
-    /// ## Resolution
-    ///
-    /// This is a generic error. Refer to the specific error message for further details.
-    #[error("Out of memory")]
-    #[diagnostic(code(nu::shell::out_of_memory))]
-    OutOfMemoryError {
-        msg: String,
-        #[label("{msg}")]
-        span: Span,
-    },
-
     /// Tried to `cd` to a path that isn't a directory.
     ///
     /// ## Resolution
@@ -859,19 +884,6 @@ pub enum ShellError {
         span: Span,
     },
 
-    /// Attempted to perform an operation on a directory that doesn't exist.
-    ///
-    /// ## Resolution
-    ///
-    /// Make sure the directory in the error message actually exists before trying again.
-    #[error("Directory not found")]
-    #[diagnostic(code(nu::shell::directory_not_found_custom))]
-    DirectoryNotFoundCustom {
-        msg: String,
-        #[label("{msg}")]
-        span: Span,
-    },
-
     /// The requested move operation cannot be completed. This is typically because both paths exist,
     /// but are of different types. For example, you might be trying to overwrite an existing file with
     /// a directory.
@@ -890,22 +902,6 @@ pub enum ShellError {
         destination_span: Span,
     },
 
-    /// The requested move operation cannot be completed. This is typically because both paths exist,
-    /// but are of different types. For example, you might be trying to overwrite an existing file with
-    /// a directory.
-    ///
-    /// ## Resolution
-    ///
-    /// Make sure the destination path does not exist before moving a directory.
-    #[error("Move not possible")]
-    #[diagnostic(code(nu::shell::move_not_possible_single))]
-    // NOTE: Currently not actively used.
-    MoveNotPossibleSingle {
-        msg: String,
-        #[label("{msg}")]
-        span: Span,
-    },
-
     /// Failed to create either a file or directory.
     ///
     /// ## Resolution
@@ -1115,15 +1111,6 @@ pub enum ShellError {
         span: Span,
     },
 
-    /// Non-Unicode input received.
-    ///
-    /// ## Resolution
-    ///
-    /// Check that your path is UTF-8 compatible.
-    #[error("Non-Unicode input received.")]
-    #[diagnostic(code(nu::shell::non_unicode_input))]
-    NonUnicodeInput,
-
     // It should be only used by commands accepts block, and accept inputs from pipeline.
     /// Failed to eval block with specific pipeline input.
     #[error("Eval block failed with pipeline input")]
@@ -1308,6 +1295,22 @@ This is an internal Nushell error, please file an issue https://github.com/nushe
         span: Span,
     },
 
+    /// Lists are not automatically spread when calling external commands
+    ///
+    /// ## Resolution
+    ///
+    /// Use the spread operator (put a '...' before the argument)
+    #[error("Lists are not automatically spread when calling external commands")]
+    #[diagnostic(
+        code(nu::shell::cannot_pass_list_to_external),
+        help("Either convert the list to a string or use the spread operator, like so: ...{arg}")
+    )]
+    CannotPassListToExternal {
+        arg: String,
+        #[label = "Spread operator (...) is necessary to spread lists"]
+        span: Span,
+    },
+
     /// Out of bounds.
     ///
     /// ## Resolution
@@ -1323,6 +1326,21 @@ This is an internal Nushell error, please file an issue https://github.com/nushe
         #[label = "byte index is not a char boundary or is out of bounds of the input"]
         span: Span,
     },
+
+    /// The config directory could not be found
+    #[error("The config directory could not be found")]
+    #[diagnostic(
+        code(nu::shell::config_dir_not_found),
+        help(
+            r#"On Linux, this would be $XDG_CONFIG_HOME or $HOME/.config.
+On MacOS, this would be `$HOME/Library/Application Support`.
+On Windows, this would be %USERPROFILE%\AppData\Roaming"#
+        )
+    )]
+    ConfigDirNotFound {
+        #[label = "Could not find config directory"]
+        span: Option<Span>,
+    },
 }
 
 // TODO: Implement as From trait
@@ -1345,6 +1363,15 @@ impl From<std::io::Error> for ShellError {
     }
 }
 
+impl From<Spanned<std::io::Error>> for ShellError {
+    fn from(error: Spanned<std::io::Error>) -> Self {
+        ShellError::IOErrorSpanned {
+            msg: error.item.to_string(),
+            span: error.span,
+        }
+    }
+}
+
 impl std::convert::From<Box<dyn std::error::Error>> for ShellError {
     fn from(input: Box<dyn std::error::Error>) -> ShellError {
         ShellError::IOError {
