@@ -14,27 +14,25 @@ impl SecondCustomValue {
     }
 
     pub fn into_value(self, span: Span) -> Value {
-        Value::CustomValue {
-            val: Box::new(self),
-            span,
-        }
+        Value::custom_value(Box::new(self), span)
     }
 
     pub fn try_from_value(value: &Value) -> Result<Self, ShellError> {
+        let span = value.span();
         match value {
-            Value::CustomValue { val, span } => match val.as_any().downcast_ref::<Self>() {
+            Value::CustomValue { val, .. } => match val.as_any().downcast_ref::<Self>() {
                 Some(value) => Ok(value.clone()),
                 None => Err(ShellError::CantConvert {
                     to_type: "cool".into(),
                     from_type: "non-cool".into(),
-                    span: *span,
+                    span,
                     help: None,
                 }),
             },
             x => Err(ShellError::CantConvert {
                 to_type: "cool".into(),
                 from_type: x.get_type().to_string(),
-                span: x.span()?,
+                span,
                 help: None,
             }),
         }
@@ -44,10 +42,7 @@ impl SecondCustomValue {
 #[typetag::serde]
 impl CustomValue for SecondCustomValue {
     fn clone_value(&self, span: nu_protocol::Span) -> Value {
-        Value::CustomValue {
-            val: Box::new(self.clone()),
-            span,
-        }
+        Value::custom_value(Box::new(self.clone()), span)
     }
 
     fn value_string(&self) -> String {
@@ -55,13 +50,13 @@ impl CustomValue for SecondCustomValue {
     }
 
     fn to_base_value(&self, span: nu_protocol::Span) -> Result<Value, ShellError> {
-        Ok(Value::String {
-            val: format!(
+        Ok(Value::string(
+            format!(
                 "I used to be a DIFFERENT custom value! ({})",
                 self.something
             ),
             span,
-        })
+        ))
     }
 
     fn as_any(&self) -> &dyn std::any::Any {
